@@ -18,11 +18,7 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 """Main ansible-lint package."""
-
-from ansiblelint.rules import AnsibleLintRule
+# prerun must run before any other imports
 from ansiblelint.version import __version__
 
-__all__ = (
-    "__version__",
-    "AnsibleLintRule"  # deprecated, import it directly from rules
-)
+__all__ = ("__version__",)
