@@ -22,13 +22,12 @@
 import logging
 from functools import lru_cache
 from itertools import product
-from typing import Any, Generator, List, Sequence
+from typing import Any, Generator, List, Optional, Sequence
 
 import ruamel.yaml
 
-from ansiblelint.constants import FileType
-
-INLINE_SKIP_FLAG = '# noqa '
+from ansiblelint.config import used_old_tags
+from ansiblelint.constants import RENAMED_TAGS, FileType
 
 _logger = logging.getLogger(__name__)
 
@@ -41,11 +40,14 @@ _logger = logging.getLogger(__name__)
 
 def get_rule_skips_from_line(line: str) -> List:
     """Return list of rule ids skipped via comment on the line of yaml."""
-    _before_noqa, _noqa_marker, noqa_text = line.partition(INLINE_SKIP_FLAG)
+    _before_noqa, _noqa_marker, noqa_text = line.partition("# noqa")
+    noqa_text = noqa_text.lstrip(" :")
     return noqa_text.split()
 
 
-def append_skipped_rules(pyyaml_data: str, file_text: str, file_type: FileType) -> Sequence:
+def append_skipped_rules(
+    pyyaml_data: str, file_text: str, file_type: Optional[FileType] = None
+) -> Sequence:
     """Append 'skipped_rules' to individual tasks or single metadata block.
 
     For a file, uses 2nd parser (ruamel.yaml) to pull comments out of
@@ -80,7 +82,9 @@ def load_data(file_text: str) -> Any:
     return yaml.load(file_text)
 
 
-def _append_skipped_rules(pyyaml_data: Sequence, file_text: str, file_type: FileType) -> Sequence:
+def _append_skipped_rules(
+    pyyaml_data: Sequence[Any], file_text: str, file_type: Optional[FileType] = None
+) -> Sequence:
     # parse file text using 2nd parser library
     ruamel_data = load_data(file_text)
 
@@ -101,6 +105,8 @@ def _append_skipped_rules(pyyaml_data: Sequence, file_text: str, file_type: File
             # assume it is a playbook, check needs to be added higher in the
             # call stack, and can remove this except
             return pyyaml_data
+    elif file_type in ['yaml', 'requirements', 'vars']:
+        return pyyaml_data
     else:
         raise RuntimeError('Unexpected file type: {}'.format(file_type))
 
@@ -150,11 +156,10 @@ def _get_tasks_from_blocks(task_blocks: Sequence) -> Generator:
     ]
 
     def get_nested_tasks(task: Any) -> Generator[Any, None, None]:
-        return (
-            subtask
-            for k in NESTED_TASK_KEYS if task and k in task
-            for subtask in task[k]
-        )
+        for k in NESTED_TASK_KEYS:
+            if task and k in task and task[k]:
+                for subtask in task[k]:
+                    yield subtask
 
     for task in task_blocks:
         for sub_task in get_nested_tasks(task):
@@ -186,4 +191,12 @@ def _get_rule_skips_from_yaml(yaml_input: Sequence) -> Sequence:
         for line in comment_obj_str.split(r'\n'):
             rule_id_list.extend(get_rule_skips_from_line(line))
 
-    return rule_id_list
+    return [normalize_tag(tag) for tag in rule_id_list]
+
+
+def normalize_tag(tag: str) -> str:
+    """Return current name of tag."""
+    if tag in RENAMED_TAGS:
+        used_old_tags[tag] = RENAMED_TAGS[tag]
+        return RENAMED_TAGS[tag]
+    return tag
